@@ -33,7 +33,7 @@ def predict(text_input):
     #running due diligence ranking module
     # due diligence ranking dictionary
     embeddings_text = similarity_model.encode([text_input])
-    embeddings_df = pd.DataFrame('embeddings.csv')
+    embeddings_df = pd.DataFrame('./embeddings.csv')
     
     
     if edd_label == 'Remediation Activities':
